@@ -1,8 +1,13 @@
 use {
-    git2::{self, Repository, Status},
-    ahash::AHashMap,
-    std::{
-        path::{Path, PathBuf},
+    git2::{
+        self,
+        Repository,
+        Status,
+    },
+    rustc_hash::FxHashMap,
+    std::path::{
+        Path,
+        PathBuf,
     },
 };
 
@@ -17,7 +22,10 @@ pub struct LineGitStatus {
 }
 
 impl LineGitStatus {
-    pub fn from(repo: &Repository, relative_path: &Path) -> Option<LineGitStatus> {
+    pub fn from(
+        repo: &Repository,
+        relative_path: &Path,
+    ) -> Option<LineGitStatus> {
         repo.status_file(relative_path)
             .ok()
             .map(|status| LineGitStatus { status })
@@ -31,12 +39,12 @@ impl LineGitStatus {
 /// looks at all the statuses of the repo and build a map path->status
 /// which can then be efficiently queried
 pub struct LineStatusComputer {
-    interesting_statuses: AHashMap<PathBuf, Status>,
+    interesting_statuses: FxHashMap<PathBuf, Status>,
 }
 impl LineStatusComputer {
     pub fn from(repo: Repository) -> Option<Self> {
         let workdir = repo.workdir()?;
-        let mut interesting_statuses = AHashMap::default();
+        let mut interesting_statuses = FxHashMap::default();
         let statuses = repo.statuses(None).ok()?;
         for entry in statuses.iter() {
             let status = entry.status();
@@ -47,14 +55,22 @@ impl LineStatusComputer {
                 }
             }
         }
-        Some(Self { interesting_statuses })
+        Some(Self {
+            interesting_statuses,
+        })
     }
-    pub fn line_status(&self, path: &Path) -> Option<LineGitStatus> {
+    pub fn line_status(
+        &self,
+        path: &Path,
+    ) -> Option<LineGitStatus> {
         self.interesting_statuses
             .get(path)
             .map(|&status| LineGitStatus { status })
     }
-    pub fn is_interesting(&self, path: &Path) -> bool {
+    pub fn is_interesting(
+        &self,
+        path: &Path,
+    ) -> bool {
         self.interesting_statuses.contains_key(path)
     }
 }
@@ -73,15 +89,13 @@ impl TreeGitStatus {
             .ok()
             .and_then(|head| head.shorthand().map(String::from));
         let stats = match repo.diff_index_to_workdir(None, None) {
-            Ok(diff) => {
-                match diff.stats() {
-                    Ok(stats) => stats,
-                    Err(e) => {
-                        debug!("get stats failed : {:?}", e);
-                        return None;
-                    }
+            Ok(diff) => match diff.stats() {
+                Ok(stats) => stats,
+                Err(e) => {
+                    debug!("get stats failed : {:?}", e);
+                    return None;
                 }
-            }
+            },
             Err(e) => {
                 debug!("get diff failed : {:?}", e);
                 return None;
